JS_WriteUint32PairUnchecked

Function JS_WriteUint32PairUnchecked 

pub unsafe extern "C" fn JS_WriteUint32PairUnchecked(
    w: *mut JSStructuredCloneWriter,
    tag: u32,
    data: u32,
) -> bool
Same as JS_WriteUint32Pair but let implicit conversions from integers of a wider range happen without performing bounds checks. Using this function directly is not recommended: it is here mainly to allow compiler optimizations in JS_WriteUint32Pair for cases where integer values are known at compile time (in which case .isValid() calls can be elided)